@@ -1,4 +1,4 @@
-# Copyright 2011-2012 Splunk, Inc.
+# Copyright 2011-2013 Splunk, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"): you may
 # not use this file except in compliance with the License. You may obtain
@@ -12,24 +12,24 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-"""The **splunklib.binding** module provides a low-level binding interface to the 
+"""The **splunklib.binding** module provides a low-level binding interface to the
 `Splunk REST API <http://docs.splunk.com/Documentation/Splunk/latest/RESTAPI/RESTcontents>`_.
 
-This module handles the wire details of calling the REST API, such as 
-authentication tokens, prefix paths, URL encoding, and so on. Actual path 
-segments, ``GET`` and ``POST`` arguments, and the parsing of responses is left 
+This module handles the wire details of calling the REST API, such as
+authentication tokens, prefix paths, URL encoding, and so on. Actual path
+segments, ``GET`` and ``POST`` arguments, and the parsing of responses is left
 to the user.
 
-If you want a friendlier interface to the Splunk REST API, use the 
+If you want a friendlier interface to the Splunk REST API, use the
 :mod:`splunklib.client` module.
 """
 
 import httplib
+import logging
 import socket
 import ssl
 import urllib
-import functools
-import logging
+
 from datetime import datetime
 from functools import wraps
 from StringIO import StringIO
@@ -48,7 +48,7 @@ __all__ = [
     "HTTPError"
 ]
 
-# If you change these, update the docstring 
+# If you change these, update the docstring
 # on _authority as well.
 DEFAULT_HOST = "localhost"
 DEFAULT_PORT = "8089"
@@ -64,6 +64,7 @@ def _log_duration(f):
         return val
     return new_f
 
+
 # Singleton values to eschew None
 class _NoAuthenticationToken(object):
     """The value stored in a :class:`Context` or :class:`splunklib.client.Service`
@@ -71,7 +72,7 @@ class _NoAuthenticationToken(object):
 
     If a ``Context`` or ``Service`` object is created without an authentication
     token, and there has not yet been a call to the ``login`` method, the token
-    field of the ``Context`` or ``Service`` object is set to 
+    field of the ``Context`` or ``Service`` object is set to
     ``_NoAuthenticationToken``.
 
     Likewise, after a ``Context`` or ``Service`` object has been logged out, the
@@ -79,24 +80,25 @@ class _NoAuthenticationToken(object):
     """
     pass
 
+
 class UrlEncoded(str):
     """This class marks URL-encoded strings.
     It should be considered an SDK-private implementation detail.
 
-    Manually tracking whether strings are URL encoded can be difficult. Avoid 
-    calling ``urllib.quote`` to replace special characters with escapes. When 
-    you receive a URL-encoded string, *do* use ``urllib.unquote`` to replace 
-    escapes with single characters. Then, wrap any string you want to use as a 
-    URL in ``UrlEncoded``. Note that because the ``UrlEncoded`` class is 
+    Manually tracking whether strings are URL encoded can be difficult. Avoid
+    calling ``urllib.quote`` to replace special characters with escapes. When
+    you receive a URL-encoded string, *do* use ``urllib.unquote`` to replace
+    escapes with single characters. Then, wrap any string you want to use as a
+    URL in ``UrlEncoded``. Note that because the ``UrlEncoded`` class is
     idempotent, making multiple calls to it is OK.
-    
-    ``UrlEncoded`` objects are identical to ``str`` objects (including being 
-    equal if their contents are equal) except when passed to ``UrlEncoded`` 
+
+    ``UrlEncoded`` objects are identical to ``str`` objects (including being
+    equal if their contents are equal) except when passed to ``UrlEncoded``
     again.
-    
-    ``UrlEncoded`` removes the ``str`` type support for interpolating values 
-    with ``%`` (doing that raises a ``TypeError``). There is no reliable way to 
-    encode values this way, so instead, interpolate into a string, quoting by 
+
+    ``UrlEncoded`` removes the ``str`` type support for interpolating values
+    with ``%`` (doing that raises a ``TypeError``). There is no reliable way to
+    encode values this way, so instead, interpolate into a string, quoting by
     hand, and call ``UrlEncode`` with ``skip_encode=True``.
 
     **Example**::
@@ -240,14 +242,19 @@ def _authentication(request_fun):
                 # an AuthenticationError and give up.
                 with _handle_auth_error("Autologin failed."):
                     self.login()
-                with _handle_auth_error("Autologin succeeded, but there was an auth error on next request. Something's very wrong."):
+                with _handle_auth_error(
+                        "Autologin succeeded, but there was an auth error on "
+                        "next request. Something is very wrong."):
                     return request_fun()
             elif he.status == 401 and not self.autologin:
-                raise AuthenticationError("Request failed: Session is not logged in.", he)
+                raise AuthenticationError(
+                    "Request failed: Session is not logged in.", he)
             else:
                 raise
+
     return wrapper
 
+
 def _authority(scheme=DEFAULT_SCHEME, host=DEFAULT_HOST, port=DEFAULT_PORT):
     """Construct a URL authority from the given *scheme*, *host*, and *port*.
 
@@ -284,9 +291,9 @@ def _authority(scheme=DEFAULT_SCHEME, host=DEFAULT_HOST, port=DEFAULT_PORT):
 
         _authority(scheme="http", host="splunk.utopia.net", port="471") == \
             "http://splunk.utopia.net:471"
-        
+
     """
-    if ':' in host: 
+    if ':' in host:
         # IPv6 addresses must be enclosed in [ ] in order to be well
         # formed.
         host = '[' + host + ']'
@@ -297,16 +304,16 @@ def namespace(sharing=None, owner=None, app=None, **kwargs):
     """This function constructs a Splunk namespace.
 
     Every Splunk resource belongs to a namespace. The namespace is specified by
-    the pair of values ``owner`` and ``app`` and is governed by a ``sharing`` mode. 
-    The possible values for ``sharing`` are: "user", "app", "global" and "system", 
+    the pair of values ``owner`` and ``app`` and is governed by a ``sharing`` mode.
+    The possible values for ``sharing`` are: "user", "app", "global" and "system",
     which map to the following combinations of ``owner`` and ``app`` values:
-    
+
         "user"   => {owner}, {app}
 
         "app"    => nobody, {app}
-        
+
         "global" => nobody, {app}
-        
+
         "system" => nobody, system
 
     "nobody" is a special user name that basically means no user, and "system"
@@ -315,18 +322,18 @@ def namespace(sharing=None, owner=None, app=None, **kwargs):
     "-" is a wildcard that can be used for both ``owner`` and ``app`` values and
     refers to all users and all apps, respectively.
 
-    In general, when you specify a namespace you can specify any combination of 
+    In general, when you specify a namespace you can specify any combination of
     these three values and the library will reconcile the triple, overriding the
     provided values as appropriate.
 
     Finally, if no namespacing is specified the library will make use of the
     ``/services`` branch of the REST API, which provides a namespaced view of
-    Splunk resources equivelent to using ``owner={currentUser}`` and 
+    Splunk resources equivelent to using ``owner={currentUser}`` and
     ``app={defaultApp}``.
 
     The ``namespace`` function returns a representation of the namespace from
-    reconciling the values you provide. It ignores any keyword arguments other 
-    than ``owner``, ``app``, and ``sharing``, so you can provide ``dicts`` of 
+    reconciling the values you provide. It ignores any keyword arguments other
+    than ``owner``, ``app``, and ``sharing``, so you can provide ``dicts`` of
     configuration information without first having to extract individual keys.
 
     :param sharing: The sharing mode (the default is "user").
@@ -335,7 +342,7 @@ def namespace(sharing=None, owner=None, app=None, **kwargs):
     :type owner: ``string``
     :param app: The app context (the default is "None").
     :type app: ``string``
-    :returns: A :class:`splunklib.data.Record` containing the reconciled 
+    :returns: A :class:`splunklib.data.Record` containing the reconciled
         namespace.
 
     **Example**::
@@ -352,16 +359,17 @@ def namespace(sharing=None, owner=None, app=None, **kwargs):
         return record({'sharing': sharing, 'owner': owner, 'app': app})
     raise ValueError("Invalid value for argument: 'sharing'")
 
+
 class Context(object):
     """This class represents a context that encapsulates a splunkd connection.
 
     The ``Context`` class encapsulates the details of HTTP requests,
-    authentication, a default namespace, and URL prefixes to simplify access to 
+    authentication, a default namespace, and URL prefixes to simplify access to
     the REST API.
-            
+
     After creating a ``Context`` object, you must call its :meth:`login`
     method before you can issue requests to splunkd. Or, use the :func:`connect`
-    function to create an already-authenticated ``Context`` object. You can 
+    function to create an already-authenticated ``Context`` object. You can
     provide a session token explicitly (the same token can be shared by multiple
     ``Context`` objects) to provide authentication.
 
@@ -378,7 +386,7 @@ class Context(object):
     :param app: The app context of the namespace (optional, the default is "None").
     :type app: ``string``
     :param token: A session token. When provided, you don't need to call :meth:`login`.
-    :param username: The Splunk account username, which is used to 
+    :param username: The Splunk account username, which is used to
         authenticate the Splunk instance.
     :type username: ``string``
     :param password: The password for the Splunk account.
@@ -396,7 +404,7 @@ class Context(object):
         # Of if you already have a session token
         c = binding.Context(token="atg232342aa34324a")
     """
-    def __init__(self, handler=None, **kwargs):        
+    def __init__(self, handler=None, **kwargs):
         self.http = HttpLib(handler)
         self.token = kwargs.get("token", _NoAuthenticationToken)
         if self.token is None: # In case someone explicitly passes token=None
@@ -435,7 +443,7 @@ class Context(object):
         """Returns an open connection (socket) to the Splunk instance.
 
         This method is used for writing bulk events to an index or similar tasks
-        where the overhead of opening a connection multiple times would be 
+        where the overhead of opening a connection multiple times would be
         prohibitive.
 
         :returns: A socket.
@@ -461,19 +469,19 @@ class Context(object):
     @_authentication
     @_log_duration
     def delete(self, path_segment, owner=None, app=None, sharing=None, **query):
-        """Performs a DELETE operation at the REST path segment with the given 
+        """Performs a DELETE operation at the REST path segment with the given
         namespace and query.
 
-        This method is named to match the HTTP method. ``delete`` makes at least 
-        one round trip to the server, one additional round trip for each 303 
-        status returned, and at most two additional round trips if 
+        This method is named to match the HTTP method. ``delete`` makes at least
+        one round trip to the server, one additional round trip for each 303
+        status returned, and at most two additional round trips if
         the ``autologin`` field of :func:`connect` is set to ``True``.
 
-        If *owner*, *app*, and *sharing* are omitted, this method uses the 
-        default :class:`Context` namespace. All other keyword arguments are 
+        If *owner*, *app*, and *sharing* are omitted, this method uses the
+        default :class:`Context` namespace. All other keyword arguments are
         included in the URL as query parameters.
 
-        :raises AuthenticationError: Raised when the ``Context`` object is not 
+        :raises AuthenticationError: Raised when the ``Context`` object is not
              logged in.
         :raises HTTPError: Raised when an error occurred in a GET operation from
              *path_segment*.
@@ -485,11 +493,11 @@ class Context(object):
         :type app: ``string``
         :param sharing: The sharing mode of the namespace (optional).
         :type sharing: ``string``
-        :param query: All other keyword arguments, which are used as query 
+        :param query: All other keyword arguments, which are used as query
             parameters.
         :type query: ``string``
         :return: The response from the server.
-        :rtype: ``dict`` with keys ``body``, ``headers``, ``reason``, 
+        :rtype: ``dict`` with keys ``body``, ``headers``, ``reason``,
                 and ``status``
 
         **Example**::
@@ -519,19 +527,19 @@ class Context(object):
     @_authentication
     @_log_duration
     def get(self, path_segment, owner=None, app=None, sharing=None, **query):
-        """Performs a GET operation from the REST path segment with the given 
+        """Performs a GET operation from the REST path segment with the given
         namespace and query.
 
-        This method is named to match the HTTP method. ``get`` makes at least 
-        one round trip to the server, one additional round trip for each 303 
-        status returned, and at most two additional round trips if 
+        This method is named to match the HTTP method. ``get`` makes at least
+        one round trip to the server, one additional round trip for each 303
+        status returned, and at most two additional round trips if
         the ``autologin`` field of :func:`connect` is set to ``True``.
 
-        If *owner*, *app*, and *sharing* are omitted, this method uses the 
-        default :class:`Context` namespace. All other keyword arguments are 
+        If *owner*, *app*, and *sharing* are omitted, this method uses the
+        default :class:`Context` namespace. All other keyword arguments are
         included in the URL as query parameters.
 
-        :raises AuthenticationError: Raised when the ``Context`` object is not 
+        :raises AuthenticationError: Raised when the ``Context`` object is not
              logged in.
         :raises HTTPError: Raised when an error occurred in a GET operation from
              *path_segment*.
@@ -543,11 +551,11 @@ class Context(object):
         :type app: ``string``
         :param sharing: The sharing mode of the namespace (optional).
         :type sharing: ``string``
-        :param query: All other keyword arguments, which are used as query 
+        :param query: All other keyword arguments, which are used as query
             parameters.
         :type query: ``string``
         :return: The response from the server.
-        :rtype: ``dict`` with keys ``body``, ``headers``, ``reason``, 
+        :rtype: ``dict`` with keys ``body``, ``headers``, ``reason``,
                 and ``status``
 
         **Example**::
@@ -577,16 +585,16 @@ class Context(object):
     @_authentication
     @_log_duration
     def post(self, path_segment, owner=None, app=None, sharing=None, headers=None, **query):
-        """Performs a POST operation from the REST path segment with the given 
+        """Performs a POST operation from the REST path segment with the given
         namespace and query.
 
-        This method is named to match the HTTP method. ``post`` makes at least 
-        one round trip to the server, one additional round trip for each 303 
-        status returned, and at most two additional round trips if 
+        This method is named to match the HTTP method. ``post`` makes at least
+        one round trip to the server, one additional round trip for each 303
+        status returned, and at most two additional round trips if
         the ``autologin`` field of :func:`connect` is set to ``True``.
 
-        If *owner*, *app*, and *sharing* are omitted, this method uses the 
-        default :class:`Context` namespace. All other keyword arguments are 
+        If *owner*, *app*, and *sharing* are omitted, this method uses the
+        default :class:`Context` namespace. All other keyword arguments are
         included in the URL as query parameters.
 
         Some of Splunk's endpoints, such as ``receivers/simple`` and
@@ -596,7 +604,7 @@ class Context(object):
         body, and all other keyword arguments will be passed as
         GET-style arguments in the URL.
 
-        :raises AuthenticationError: Raised when the ``Context`` object is not 
+        :raises AuthenticationError: Raised when the ``Context`` object is not
              logged in.
         :raises HTTPError: Raised when an error occurred in a GET operation from
              *path_segment*.
@@ -610,17 +618,17 @@ class Context(object):
         :type sharing: ``string``
         :param headers: List of extra HTTP headers to send (optional).
         :type headers: ``list`` of 2-tuples.
-        :param query: All other keyword arguments, which are used as query 
+        :param query: All other keyword arguments, which are used as query
             parameters.
         :type query: ``string``
         :return: The response from the server.
-        :rtype: ``dict`` with keys ``body``, ``headers``, ``reason``, 
+        :rtype: ``dict`` with keys ``body``, ``headers``, ``reason``,
                 and ``status``
 
         **Example**::
 
             c = binding.connect(...)
-            c.post('saved/searches', name='boris', 
+            c.post('saved/searches', name='boris',
                    search='search * earliest=-1m | head 1') == \\
                 {'body': ...a response reader object...,
                  'headers': [('content-length', '10455'),
@@ -635,13 +643,13 @@ class Context(object):
             c.post('nonexistant/path') # raises HTTPError
             c.logout()
             # raises AuthenticationError:
-            c.post('saved/searches', name='boris', 
+            c.post('saved/searches', name='boris',
                    search='search * earliest=-1m | head 1')
         """
         if headers is None:
             headers = []
-        
-        path = self.authority + self._abspath(path_segment, owner=owner, 
+
+        path = self.authority + self._abspath(path_segment, owner=owner,
                                               app=app, sharing=sharing)
         logging.debug("POST request to %s (body: %s)", path, repr(query))
         all_headers = headers + self._auth_headers
@@ -653,15 +661,15 @@ class Context(object):
     def request(self, path_segment, method="GET", headers=None, body="",
                 owner=None, app=None, sharing=None):
         """Issues an arbitrary HTTP request to the REST path segment.
-        
-        This method is named to match ``httplib.request``. This function 
+
+        This method is named to match ``httplib.request``. This function
         makes a single round trip to the server.
 
-        If *owner*, *app*, and *sharing* are omitted, this method uses the 
-        default :class:`Context` namespace. All other keyword arguments are 
+        If *owner*, *app*, and *sharing* are omitted, this method uses the
+        default :class:`Context` namespace. All other keyword arguments are
         included in the URL as query parameters.
 
-        :raises AuthenticationError: Raised when the ``Context`` object is not 
+        :raises AuthenticationError: Raised when the ``Context`` object is not
              logged in.
         :raises HTTPError: Raised when an error occurred in a GET operation from
              *path_segment*.
@@ -679,11 +687,11 @@ class Context(object):
         :type app: ``string``
         :param sharing: The sharing mode of the namespace (optional).
         :type sharing: ``string``
-        :param query: All other keyword arguments, which are used as query 
+        :param query: All other keyword arguments, which are used as query
             parameters.
         :type query: ``string``
         :return: The response from the server.
-        :rtype: ``dict`` with keys ``body``, ``headers``, ``reason``, 
+        :rtype: ``dict`` with keys ``body``, ``headers``, ``reason``,
                 and ``status``
 
         **Example**::
@@ -706,12 +714,12 @@ class Context(object):
         """
         if headers is None:
             headers = []
-        
+
         path = self.authority \
-            + self._abspath(path_segment, owner=owner, 
+            + self._abspath(path_segment, owner=owner,
                             app=app, sharing=sharing)
         all_headers = headers + self._auth_headers
-        logging.debug("%s request to %s (headers: %s, body: %s)", 
+        logging.debug("%s request to %s (headers: %s, body: %s)",
                       method, path, str(all_headers), repr(body))
         response = self.http.request(path,
                                      {'method': method,
@@ -723,10 +731,10 @@ class Context(object):
         """Logs into the Splunk instance referred to by the :class:`Context`
         object.
 
-        Unless a ``Context`` is created with an explicit authentication token 
+        Unless a ``Context`` is created with an explicit authentication token
         (probably obtained by logging in from a different ``Context`` object)
-        you must call :meth:`login` before you can issue requests. 
-        The authentication token obtained from the server is stored in the 
+        you must call :meth:`login` before you can issue requests.
+        The authentication token obtained from the server is stored in the
         ``token`` field of the ``Context`` object.
 
         :raises AuthenticationError: Raised when login fails.
@@ -747,7 +755,7 @@ class Context(object):
         try:
             response = self.http.post(
                 self.authority + self._abspath("/services/auth/login"),
-                username=self.username, 
+                username=self.username,
                 password=self.password)
             body = response.body.read()
             session = XML(body).findtext("./sessionKey")
@@ -764,7 +772,7 @@ class Context(object):
         self.token = _NoAuthenticationToken
         return self
 
-    def _abspath(self, path_segment, 
+    def _abspath(self, path_segment,
                 owner=None, app=None, sharing=None):
         """Qualifies *path_segment* into an absolute path for a URL.
 
@@ -780,8 +788,8 @@ class Context(object):
 
         :param path_segment: A relative or absolute URL path segment.
         :type path_segment: ``string``
-        :param owner, app, sharing: Components of a namespace (defaults 
-                                    to the ``Context``'s namespace if all 
+        :param owner, app, sharing: Components of a namespace (defaults
+                                    to the ``Context``'s namespace if all
                                     three are omitted)
         :type owner, app, sharing: ``string``
         :return: A ``UrlEncoded`` (a subclass of ``str``).
@@ -825,6 +833,7 @@ class Context(object):
                           skip_encode=skip_encode)
         return path
 
+
 def connect(**kwargs):
     """This function returns an authenticated :class:`Context` object.
 
@@ -844,15 +853,15 @@ def connect(**kwargs):
     :type app: ``string``
     :param sharing: The sharing mode for the namespace (the default is "user").
     :type sharing: "global", "system", "app", or "user"
-    :param token: The current session token (optional). Session tokens can be 
+    :param token: The current session token (optional). Session tokens can be
         shared across multiple service instances.
     :type token: ``string``
-    :param username: The Splunk account username, which is used to 
+    :param username: The Splunk account username, which is used to
         authenticate the Splunk instance.
     :type username: ``string``
     :param password: The password for the Splunk account.
     :type password: ``string``
-    :param autologin: When ``True``, automatically tries to log in again if the 
+    :param autologin: When ``True``, automatically tries to log in again if the
         session terminates.
     :type autologin: ``Boolean``
     :return: An initialized :class:`Context` instance.
@@ -868,7 +877,7 @@ def connect(**kwargs):
     return c
 
 # Note: the error response schema supports multiple messages but we only
-# return the first, although we do return the body so that an exception 
+# return the first, although we do return the body so that an exception
 # handler that wants to read multiple messages can do so.
 class HTTPError(Exception):
     """This exception is raised for HTTP responses that return an error."""
@@ -879,7 +888,7 @@ class HTTPError(Exception):
         detail = XML(body).findtext("./messages/msg")
         message = "HTTP %d %s%s" % (
             status, reason, "" if detail is None else " -- %s" % detail)
-        Exception.__init__(self, _message or message) 
+        Exception.__init__(self, _message or message)
         self.status = status
         self.reason = reason
         self.headers = response.headers
@@ -897,7 +906,7 @@ class AuthenticationError(HTTPError):
         # Put the body back in the response so that HTTPError's constructor can
         # read it again.
         cause._response.body = StringIO(cause.body)
-        
+
         HTTPError.__init__(self, cause._response, message)
 
 #
@@ -922,9 +931,9 @@ class AuthenticationError(HTTPError):
 #
 
 # Encode the given kwargs as a query string. This wrapper will also _encode
-# a list value as a sequence of assignemnts to the corresponding arg name, 
+# a list value as a sequence of assignemnts to the corresponding arg name,
 # for example an argument such as 'foo=[1,2,3]' will be encoded as
-# 'foo=1&foo=2&foo=3'. 
+# 'foo=1&foo=2&foo=3'.
 def _encode(**kwargs):
     items = []
     for key, value in kwargs.iteritems():
@@ -949,12 +958,12 @@ def _spliturl(url):
 class HttpLib(object):
     """A set of convenient methods for making HTTP calls.
 
-    ``HttpLib`` provides a general :meth:`request` method, and :meth:`delete`, 
+    ``HttpLib`` provides a general :meth:`request` method, and :meth:`delete`,
     :meth:`post`, and :meth:`get` methods for the three HTTP methods that Splunk
     uses.
 
     By default, ``HttpLib`` uses Python's built-in ``httplib`` library,
-    but you can replace it by passing your own handling function to the 
+    but you can replace it by passing your own handling function to the
     constructor for ``HttpLib``.
 
     The handling function should have the type:
@@ -968,7 +977,7 @@ class HttpLib(object):
 
         - headers: A list of pairs specifying the HTTP headers (for example: ``[('key': value), ...]``).
 
-        - body: A string containing the body to send with the request (this string 
+        - body: A string containing the body to send with the request (this string
           should default to '').
 
     and ``response_dict`` is a dictionary with the following keys:
@@ -984,7 +993,7 @@ class HttpLib(object):
 
     The response dictionary is returned directly by ``HttpLib``'s methods with
     no further processing. By default, ``HttpLib`` calls the :func:`handler` function
-    to get a handler function. 
+    to get a handler function.
     """
     def __init__(self, custom_handler=None):
         self.handler = handler() if custom_handler is None else custom_handler
@@ -994,12 +1003,12 @@ class HttpLib(object):
 
         :param url: The URL.
         :type url: ``string``
-        :param headers: A list of pairs specifying the headers for the HTTP 
+        :param headers: A list of pairs specifying the headers for the HTTP
             response (for example, ``[('Content-Type': 'text/cthulhu'), ('Token': 'boris')]``).
         :type headers: ``list``
         :param kwargs: Additional keyword arguments (optional). These arguments
-            are interpreted as the query part of the URL. The order of keyword 
-            arguments is not preserved in the request, but the keywords and 
+            are interpreted as the query part of the URL. The order of keyword
+            arguments is not preserved in the request, but the keywords and
             their arguments will be URL encoded.
         :type kwargs: ``dict``
         :returns: A dictionary describing the response (see :class:`HttpLib` for
@@ -1007,7 +1016,7 @@ class HttpLib(object):
         :rtype: ``dict``
         """
         if headers is None: headers = []
-        if kwargs: 
+        if kwargs:
             # url is already a UrlEncoded. We have to manually declare
             # the query to be encoded or it will get automatically URL
             # encoded by being appended to url.
@@ -1019,16 +1028,16 @@ class HttpLib(object):
         return self.request(url, message)
 
     def get(self, url, headers=None, **kwargs):
-        """Sends a GET request to a URL. 
+        """Sends a GET request to a URL.
 
         :param url: The URL.
         :type url: ``string``
-        :param headers: A list of pairs specifying the headers for the HTTP 
+        :param headers: A list of pairs specifying the headers for the HTTP
             response (for example, ``[('Content-Type': 'text/cthulhu'), ('Token': 'boris')]``).
         :type headers: ``list``
         :param kwargs: Additional keyword arguments (optional). These arguments
-            are interpreted as the query part of the URL. The order of keyword 
-            arguments is not preserved in the request, but the keywords and 
+            are interpreted as the query part of the URL. The order of keyword
+            arguments is not preserved in the request, but the keywords and
             their arguments will be URL encoded.
         :type kwargs: ``dict``
         :returns: A dictionary describing the response (see :class:`HttpLib` for
@@ -1036,7 +1045,7 @@ class HttpLib(object):
         :rtype: ``dict``
         """
         if headers is None: headers = []
-        if kwargs: 
+        if kwargs:
             # url is already a UrlEncoded. We have to manually declare
             # the query to be encoded or it will get automatically URL
             # encoded by being appended to url.
@@ -1048,13 +1057,13 @@ class HttpLib(object):
 
         :param url: The URL.
         :type url: ``string``
-        :param headers: A list of pairs specifying the headers for the HTTP 
+        :param headers: A list of pairs specifying the headers for the HTTP
             response (for example, ``[('Content-Type': 'text/cthulhu'), ('Token': 'boris')]``).
         :type headers: ``list``
-        :param kwargs: Additional keyword arguments (optional). If the argument 
-            is ``body``, the value is used as the body for the request, and the 
-            keywords and their arguments will be URL encoded. If there is no 
-            ``body`` keyword argument, all the keyword arguments are encoded 
+        :param kwargs: Additional keyword arguments (optional). If the argument
+            is ``body``, the value is used as the body for the request, and the
+            keywords and their arguments will be URL encoded. If there is no
+            ``body`` keyword argument, all the keyword arguments are encoded
             into the body of the request in the format ``x-www-form-urlencoded``.
         :type kwargs: ``dict``
         :returns: A dictionary describing the response (see :class:`HttpLib` for
@@ -1083,8 +1092,8 @@ class HttpLib(object):
 
         :param url: The URL.
         :type url: ``string``
-        :param message: A dictionary with the format as described in 
-            :class:`HttpLib`. 
+        :param message: A dictionary with the format as described in
+            :class:`HttpLib`.
         :type message: ``dict``
         :param kwargs: Additional keyword arguments (optional). These arguments
             are passed unchanged to the handler.
@@ -1096,15 +1105,16 @@ class HttpLib(object):
         response = self.handler(url, message, **kwargs)
         response = record(response)
         if 400 <= response.status:
-            raise HTTPError(response) 
+            raise HTTPError(response)
         return response
 
+
 # Converts an httplib response into a file-like object.
 class ResponseReader(object):
     """This class provides a file-like interface for :class:`httplib` responses.
 
     The ``ResponseReader`` class is intended to be a layer to unify the different
-    types of HTTP libraries used with this SDK. This class also provides a 
+    types of HTTP libraries used with this SDK. This class also provides a
     preview of the stream and a few useful predicates.
     """
     # For testing, you can use a StringIO as the argument to
@@ -1123,12 +1133,12 @@ class ResponseReader(object):
         return self.peek(1) == ""
 
     def peek(self, size):
-        """Nondestructively retrieves a given number of characters. 
+        """Nondestructively retrieves a given number of characters.
 
-        The next :meth:`read` operation behaves as though this method was never 
-        called. 
+        The next :meth:`read` operation behaves as though this method was never
+        called.
 
-        :param size: The number of characters to retrieve. 
+        :param size: The number of characters to retrieve.
         :type size: ``integer``
         """
         c = self.read(size)
@@ -1141,7 +1151,7 @@ class ResponseReader(object):
 
     def read(self, size = None):
         """Reads a given number of characters from the response.
-        
+
         :param size: The number of characters to read, or "None" to read the
             entire response.
         :type size: ``integer`` or "None"
@@ -1154,6 +1164,7 @@ class ResponseReader(object):
         r = r + self._response.read(size)
         return r
 
+
 def handler(key_file=None, cert_file=None, timeout=None):
     """This class returns an instance of the default HTTP request handler using
     the values you provide.
@@ -1180,27 +1191,27 @@ def handler(key_file=None, cert_file=None, timeout=None):
     def request(url, message, **kwargs):
         scheme, host, port, path = _spliturl(url)
         body = message.get("body", "")
-        head = { 
+        head = {
             "Content-Length": str(len(body)),
             "Host": host,
             "User-Agent": "splunk-sdk-python/0.1",
             "Accept": "*/*",
         } # defaults
-        for key, value in message["headers"]: 
+        for key, value in message["headers"]:
             head[key] = value
         method = message.get("method", "GET")
 
         connection = connect(scheme, host, port)
         try:
             connection.request(method, path, body, head)
-            if timeout is not None: 
+            if timeout is not None:
                 connection.sock.settimeout(timeout)
             response = connection.getresponse()
         finally:
             connection.close()
 
         return {
-            "status": response.status, 
+            "status": response.status,
             "reason": response.reason,
             "headers": response.getheaders(),
             "body": ResponseReader(response),
